@@ -9,7 +9,7 @@ var indexSectionsWithContent =
   6: "be",
   7: "be",
   8: "bdehilo",
-  9: "dl"
+  9: "abcdefhilnorstu"
 };
 
 var indexSectionNames =
